aboutsummaryrefslogtreecommitdiff
path: root/MediaBrowser.Model/Entities
diff options
context:
space:
mode:
authorLuke Pulverenti <luke.pulverenti@gmail.com>2015-04-04 15:35:29 -0400
committerLuke Pulverenti <luke.pulverenti@gmail.com>2015-04-04 15:35:29 -0400
commit2b7a80cfb5b9212260734c095a5b3439af7d64e2 (patch)
treeab746cd05a2244b4c8c8432a30090b85c9d4d986 /MediaBrowser.Model/Entities
parent8c61abf6d23510da8eaddf3894f9e14f88dc5f22 (diff)
improve direct play of live streams
Diffstat (limited to 'MediaBrowser.Model/Entities')
-rw-r--r--MediaBrowser.Model/Entities/MediaInfo.cs61
1 files changed, 50 insertions, 11 deletions
diff --git a/MediaBrowser.Model/Entities/MediaInfo.cs b/MediaBrowser.Model/Entities/MediaInfo.cs
index ef26cfa14..67efe3108 100644
--- a/MediaBrowser.Model/Entities/MediaInfo.cs
+++ b/MediaBrowser.Model/Entities/MediaInfo.cs
@@ -1,26 +1,65 @@
+using MediaBrowser.Model.Dto;
+using System;
using System.Collections.Generic;
namespace MediaBrowser.Model.Entities
{
- public class MediaInfo
+ public class MediaInfo : MediaSourceInfo, IHasProviderIds
{
+ public List<ChapterInfo> Chapters { get; set; }
+
/// <summary>
/// Gets or sets the media streams.
/// </summary>
- /// <value>The media streams.</value>
- public List<MediaStream> MediaStreams { get; set; }
-
+ /// <value>The title.</value>
+ public string Title { get; set; }
/// <summary>
/// Gets or sets the format.
/// </summary>
- /// <value>The format.</value>
- public string Format { get; set; }
-
- public int? TotalBitrate { get; set; }
+ /// <value>The album.</value>
+ public string Album { get; set; }
+ /// <summary>
+ /// Gets or sets the artists.
+ /// </summary>
+ /// <value>The artists.</value>
+ public List<string> Artists { get; set; }
+ /// <summary>
+ /// Gets or sets the album artists.
+ /// </summary>
+ /// <value>The album artists.</value>
+ public List<string> AlbumArtists { get; set; }
+ /// <summary>
+ /// Gets or sets the studios.
+ /// </summary>
+ /// <value>The studios.</value>
+ public List<string> Studios { get; set; }
+ public List<string> Genres { get; set; }
+ public int? IndexNumber { get; set; }
+ public int? ParentIndexNumber { get; set; }
+ public int? ProductionYear { get; set; }
+ public DateTime? PremiereDate { get; set; }
+ public List<BaseItemPerson> People { get; set; }
+ public Dictionary<string, string> ProviderIds { get; set; }
+ /// <summary>
+ /// Gets or sets the official rating.
+ /// </summary>
+ /// <value>The official rating.</value>
+ public string OfficialRating { get; set; }
+ /// <summary>
+ /// Gets or sets the overview.
+ /// </summary>
+ /// <value>The overview.</value>
+ public string Overview { get; set; }
public MediaInfo()
{
- MediaStreams = new List<MediaStream>();
+ Chapters = new List<ChapterInfo>();
+ Artists = new List<string>();
+ AlbumArtists = new List<string>();
+ Studios = new List<string>();
+ Genres = new List<string>();
+ People = new List<BaseItemPerson>();
+ ProviderIds = new Dictionary<string, string>(StringComparer.OrdinalIgnoreCase);
}
}
} \ No newline at end of file
@@ -1,26 +1,65 @@
/// <summary>
- /// Gets or sets the media streams.
+ /// Gets or sets the title.
/// </summary>
@@ -1,26 +1,65 @@
/// <summary>
- /// Gets or sets the format.
+ /// Gets or sets the album.
/// </summary>